@@ -35,3 +35,7 @@ class Client:
 
   def send_json(self, j):
     self._send(Client._encode_json(j))
+
+  def send_as_user(self, msg):
+    j = {"send_as_user": msg}
+    self._send(Client._encode_json(j))
